@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 import os
 import sys
@@ -155,6 +155,9 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):
         self.prefix = prefix
         self.interval = interval
 
+        self.on_connect = self.on_connect_callback
+        self.on_message = self.on_message_callback
+
     def disconnect(self, reasoncode=None, properties=None):
         self.publish(topic=f'{self.prefix}/mqtt/weconnectConnected', payload=False)
         super().disconnect(reasoncode, properties)
@@ -167,7 +170,8 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):
     def updateWeConnect(self):
         LOG.info('Update data from WeConnect')
         self.weConnect.update()
-        self.publish(topic=f'{self.prefix}/mqtt/weconnectUpdated', payload=str(datetime.now()))
+        self.publish(topic=f'{self.prefix}/mqtt/weconnectUpdated',
+                     payload=datetime.utcnow().replace(microsecond=0, tzinfo=timezone.utc).isoformat())
 
     def onWeConnectEvent(self, element, flags):
         if flags & addressable.AddressableLeaf.ObserverEvent.VALUE_CHANGED:
@@ -177,10 +181,14 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):
                 convertedValue = element.value.value
             else:
                 convertedValue = str(element.value)
-
+            LOG.debug('%s%s, value changed: new value is: %s', self.prefix, element.getGlobalAddress(), convertedValue)
             self.publish(topic=f'{self.prefix}{element.getGlobalAddress()}', payload=convertedValue)
 
-    def on_connect(self, mqttc, obj, flags, rc):  # pylint: disable=W0221,W0236,W0613
+    def on_connect_callback(self, mqttc, obj, flags, rc):
+        del mqttc  # unused
+        del obj  # unused
+        del flags  # unused
+
         if rc == 0:
             LOG.info('Connected to MQTT broker')
             self.publish(topic=f'{self.prefix}/mqtt/weconnectForceUpdate', payload=False)
@@ -208,7 +216,10 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):
             print('Could not connect: %d', rc, file=sys.stderr)
             sys.exit(1)
 
-    def on_message(self, mqttc, obj, msg):  # pylint: disable=W0221,W0236,W0613
+    def on_message_callback(self, mqttc, obj, msg):
+        del mqttc  # unused
+        del obj  # unused
+
         if msg.topic == f'{self.prefix}/mqtt/weconnectForceUpdate':
             if msg.payload.lower() == b'True'.lower():
                 LOG.info('Update triggered by MQTT message')
